@@ -1,5 +1,4 @@
 context("periscope - UI functionality")
-skip_on_cran()
 
 
 test_that("fw_create_header", {
@@ -305,7 +304,13 @@ test_that("fw_create_right_sidebar", {
 
     expect_equal(result1.children$name, "style")
     expect_equal(length(result1.children$attribs), 0)
+})
 
+test_that("fw_create_right_sidebar SDP<2", {
+    skip_if_not(t_sdp_old)
+    
+    result <- periscope:::fw_create_right_sidebar()
+    
     expect_equal(result[[2]]$name, "div")
     expect_equal(result[[2]]$attribs, list(id = "controlbar"))
     expect_equal(length(result[[2]]$children), 2)
@@ -323,60 +328,82 @@ test_that("fw_create_right_sidebar", {
 
     expect_equal(result2.children[[2]]$name, "div")
     expect_equal(result2.children[[2]]$attribs, list(class = "control-sidebar-bg", style = "width: 230px;"))
-    
+
     add_ui_sidebar_right(elementlist = list(selectInput(inputId = "id", choices = 1:3, label = "Input widget")))
     result <- periscope:::fw_create_right_sidebar()
-    
+
     expect_equal(length(result), 2)
     expect_equal(result[[1]]$name, "head")
     expect_equal(length(result[[1]]$attribs), 0)
     expect_equal(length(result[[1]]$children), 1)
-    
+
     result1.children <- result[[1]]$children[[1]]
-    
+
     expect_equal(result1.children$name, "style")
     expect_equal(length(result1.children$attribs), 0)
-    
+
     expect_equal(result[[2]]$name, "div")
     expect_equal(result[[2]]$attribs, list(id = "controlbar"))
     expect_equal(length(result[[2]]$children), 2)
-    
+
     result2.children <- result[[2]]$children
-    
+
     expect_equal(result2.children[[1]]$name, "aside")
     expect_equal(length(result2.children[[1]]$children), 2)
-    
+
     expect_equal(result2.children[[1]]$children[[1]]$name, "ul")
     expect_equal(result2.children[[1]]$children[[1]]$attribs, list(class = "nav nav-tabs nav-justified control-sidebar-tabs"))
-    
+
     expect_equal(result2.children[[1]]$children[[2]]$name, "div")
     expect_equal(result2.children[[1]]$children[[2]]$attribs, list(class = "controlbar tab-content"))
-    
+
     result2.1.2.children <- result2.children[[1]]$children[[2]]$children
-    
+
     expect_equal(result2.1.2.children[[1]]$name, "div")
     expect_equal(length(result2.1.2.children[[1]]$children), 1)
-    
+
     expect_equal(result2.1.2.children[[2]]$name, "div")
     expect_equal(result2.1.2.children[[2]]$attribs, list(class = "form-group shiny-input-container"))
     expect_equal(length(result2.1.2.children[[2]]$children), 2)
-    
+
     expect_equal(result2.1.2.children[[2]]$children[[1]]$name, "label")
     expect_equal(result2.1.2.children[[2]]$children[[1]]$attribs$class, "control-label")
-    
+
     expect_equal(result2.1.2.children[[2]]$children[[2]]$name, "div")
     expect_equal(length(result2.1.2.children[[2]]$children[[2]]$children), 2)
-    
+
     expect_equal(result2.1.2.children[[2]]$children[[2]]$children[[1]]$name, "select")
     expect_equal(result2.1.2.children[[2]]$children[[2]]$children[[1]]$attribs, list(id = "id"))
-    
+
     expect_equal(result2.1.2.children[[2]]$children[[2]]$children[[2]]$name, "script")
     expect_equal(result2.1.2.children[[2]]$children[[2]]$children[[2]]$attribs, list(type = "application/json", `data-for` = "id", `data-nonempty` = ""))
-    
+
     expect_equal(result2.children[[2]]$name, "div")
     expect_equal(result2.children[[2]]$attribs, list(class = "control-sidebar-bg", style = "width: 230px;"))
 })
 
+test_that("fw_create_right_sidebar SDP>=2", {
+    skip_if(t_sdp_old)
+    
+    result <- periscope:::fw_create_right_sidebar()
+    result2 <- result[[2]]
+    
+    expect_equal(length(result2), 2)
+    expect_equal(result2[[1]]$name, "aside")
+    expect_equal(result2[[1]]$attribs$id, "controlbarId")
+    
+    result2.1child <- result2[[1]]$children
+    
+    expect_equal(length(result2.1child), 1)
+
+    expect_equal(length(result2.1child[[1]][[1]]), 3)
+    expect_equal(result2.1child[[1]][[1]]$name, "div")
+    expect_equal(result2.1child[[1]][[1]]$attribs$id, "sidebarRightAlert")
+    
+    result2.2child <- result2[[2]]$children
+    expect_equal(length(result2.2child), 0)
+  })
+
 test_that("add_ui_sidebar_right", {
     result <- add_ui_sidebar_right(elementlist = NULL)
     expect_null(result, "add_ui_sidebar_right")
@@ -385,7 +412,7 @@ test_that("add_ui_sidebar_right", {
 test_that("add_ui_sidebar_right with append", {
     result <- add_ui_sidebar_right(elementlist = NULL, append = TRUE)
     expect_null(result, "add_ui_sidebar_right")
-    
+
     result <- add_ui_sidebar_right(elementlist = NULL, append = FALSE)
     expect_null(result, "add_ui_sidebar_right")
 })
